import { jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState, useEffect } from 'react';
import { useJupyter } from './../../jupyter/JupyterContext';
import Lumino from '../lumino/Lumino';
import ConsoleAdapter from './ConsoleAdapter';
import useConsoleStore from './ConsoleState';
import './Console.css';
export const Console = (options) => {
    const { defaultKernel, serviceManager } = useJupyter();
    const [adapter, setAdapter] = useState();
    const store = useConsoleStore();
    useEffect(() => {
        if (serviceManager) {
            const adapter = new ConsoleAdapter({
                kernel: defaultKernel,
                serviceManager,
                code: options.code,
            });
            setAdapter(adapter);
            store.setAdapter(adapter);
        }
    }, [defaultKernel, serviceManager]);
    return adapter ? (_jsx(Lumino, { children: adapter.panel })) : (_jsx(_Fragment, { children: "Loading Jupyter Console..." }));
};
export default Console;
//# sourceMappingURL=Console.js.map