import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { memo, useState, useEffect, useMemo, useRef } from 'react';
import { Box } from '@primer/react';
import { PageConfig } from '@jupyterlab/coreutils';
import { useJupyter } from '../../jupyter/JupyterContext';
import { JupyterLabAppCorePlugins } from './JupyterLabAppPlugins';
import JupyterLabAppAdapter from './JupyterLabAppAdapter';
import JupyterLabAppCss from './JupyterLabAppCss';
// The webpack public path needs to be set before loading the CSS assets.
globalThis.__webpack_public_path__ = PageConfig.getOption('fullStaticUrl') + '/';
window.__webpack_public_path__ = PageConfig.getOption('fullStaticUrl') + '/';
const JupyterLabAppComponent = (props) => {
    const { PluginType, headless, height, hostId, onJupyterLab, onPlugin, pluginId, position, serverless, serviceManager: propsServiceManager, startDefaultKernel, theme, width, } = props;
    const { serviceManager } = useJupyter({
        serverless,
        serviceManager: propsServiceManager,
        startDefaultKernel,
    });
    const defaultMimeExtensionPromises = useMemo(() => props.mimeRendererPromises ??
        JupyterLabAppCorePlugins().mimeExtensionPromises, []);
    const defaultExtensionPromises = useMemo(() => props.pluginPromises ??
        JupyterLabAppCorePlugins().extensionPromises, []);
    const ref = useRef(null);
    const [_, setAdapter] = useState();
    useEffect(() => {
        if (ref && serviceManager) {
            const adapter = new JupyterLabAppAdapter({
                ...props,
                mimeRendererPromises: defaultMimeExtensionPromises,
                pluginPromises: defaultExtensionPromises,
                serviceManager,
            });
            adapter.ready.then(() => {
                onJupyterLab(adapter);
                if (pluginId && PluginType && onPlugin) {
                    const plugin = adapter.service(pluginId);
                    onPlugin(plugin);
                }
            });
            setAdapter(adapter);
        }
    }, [hostId, ref, serviceManager, theme]);
    return (_jsx(_Fragment, { children: _jsxs(Box, { sx: {
                '& .jp-LabShell': {
                    position: position,
                    height: height,
                    width: width,
                    display: headless ? 'none' : 'inherit',
                },
            }, children: [_jsx(JupyterLabAppCss, { theme: theme }), _jsx("div", { ref: ref, id: hostId })] }) }));
};
JupyterLabAppComponent.defaultProps = {
    devMode: false,
    disabledPlugins: [],
    headless: false,
    height: '100vh',
    hostId: 'app-example-id',
    mimeRenderers: [],
    onJupyterLab: (_) => { },
    plugins: [],
    position: 'relative',
    nosplash: false,
    serverless: false,
    startDefaultKernel: false,
    theme: 'light',
    width: '100%',
};
export const JupyterLabApp = memo(JupyterLabAppComponent);
export default JupyterLabApp;
//# sourceMappingURL=JupyterLabApp.js.map