import { DocumentRegistry } from '@jupyterlab/docregistry';
import { INotebookContent } from '@jupyterlab/nbformat';
import { INotebookModel, NotebookPanel } from '@jupyterlab/notebook';
import { IRenderMime } from '@jupyterlab/rendermime-interfaces';
import { Kernel as JupyterKernel, ServiceManager } from '@jupyterlab/services';
import { CommandRegistry } from '@lumino/commands';
import { KernelTransfer, OnSessionConnection } from '../../state';
import { ICollaborative, Kernel, Lite } from './../../jupyter';
import { INotebookToolbarProps } from './toolbar';
import './Notebook.css';
export type ExternalIPyWidgets = {
    name: string;
    version: string;
};
export type BundledIPyWidgets = ExternalIPyWidgets & {
    module: any;
};
export type IDatalayerNotebookExtensionProps = {
    notebookId: string;
    commands: CommandRegistry;
    panel: NotebookPanel;
};
export type DatalayerNotebookExtension = DocumentRegistry.IWidgetExtension<NotebookPanel, INotebookModel> & {
    init(props: IDatalayerNotebookExtensionProps): void;
    get component(): JSX.Element | null;
};
export type INotebookProps = {
    Toolbar?: (props: INotebookToolbarProps) => JSX.Element;
    cellMetadataPanel?: boolean;
    cellSidebarMargin?: number;
    collaborative?: ICollaborative;
    extensions?: DatalayerNotebookExtension[];
    height?: string;
    id: string;
    kernel?: Kernel;
    kernelClients?: JupyterKernel.IKernelConnection[];
    kernelTransfer?: KernelTransfer;
    lite?: Lite;
    maxHeight?: string;
    nbformat?: INotebookContent;
    onSessionConnection?: OnSessionConnection;
    path?: string;
    readonly?: boolean;
    renderId?: number;
    renderers?: IRenderMime.IRendererFactory[];
    serverless: boolean;
    serviceManager?: ServiceManager.IManager;
    startDefaultKernel?: boolean;
    url?: string;
    /**
     * The Kernel Id to use, as defined in the Kernel API.
     */
    useRunningKernelId?: string;
    /**
     * The index (aka position) of the Kernel to use in the list of kernels.
     */
    useRunningKernelIndex?: number;
};
/**
 * This component creates a Notebook as a collection of cells
 * with sidebars.
 *
 * @param props The notebook properties.
 * @returns A Notebook React.js component.
 */
export declare const Notebook: {
    (props: INotebookProps): import("react/jsx-runtime").JSX.Element;
    defaultProps: Partial<INotebookProps>;
};
export default Notebook;
