import React from 'react';
import type { INotebookContent } from '@jupyterlab/nbformat';
import type { NotebookModel } from '@jupyterlab/notebook';
import type { IRenderMime } from '@jupyterlab/rendermime-interfaces';
import type { ServiceManager } from '@jupyterlab/services';
import type { CommandRegistry } from '@lumino/commands';
import type { OnSessionConnection } from '../../state';
import { type CollaborationServer } from './NotebookBase';
import type { DatalayerNotebookExtension } from './Notebook';
import type { INotebookToolbarProps } from './toolbar';
import './Notebook.css';
/**
 * Simple notebook component properties
 */
export interface INotebook2Props {
    /**
     * Collaboration server providing the document rooms.
     */
    collaborationServer?: CollaborationServer;
    /**
     * Custom command registry.
     *
     * Note:
     * Providing it allows to command the component from an higher level.
     */
    commands?: CommandRegistry;
    /**
     * Notebook extensions.
     */
    extensions?: DatalayerNotebookExtension[];
    /**
     * Notebook ID.
     */
    id: string;
    /**
     * Kernel ID to connect to.
     */
    kernelId?: string;
    /**
     * Notebook initial content.
     */
    nbformat?: INotebookContent;
    /**
     * Notebook file path.
     */
    path?: string;
    /**
     * Whether the notebook is read-only or not.
     */
    readonly?: boolean;
    /**
     * Additional cell output renderers.
     */
    renderers?: IRenderMime.IRendererFactory[];
    /**
     * Jupyter service manager.
     */
    serviceManager: ServiceManager.IManager;
    /**
     * Whether to start a default kernel or not.
     */
    startDefaultKernel?: boolean;
    /**
     * React toolbar component factory.
     */
    Toolbar?: React.JSXElementConstructor<INotebookToolbarProps>;
    /**
     * URL to fetch the notebook content from.
     */
    url?: string;
    /**
     * Margin in pixels on the right side of cells.
     *
     * This is typically needed when cell sidebar is injected as extension.
     */
    cellSidebarMargin?: number;
    /**
     * CSS height of the component.
     */
    height?: string;
    /**
     * CSS max-height of the component.
     */
    maxHeight?: string;
    /**
     * Callback on notebook model changed.
     */
    onNotebookModelChanged?: (model: NotebookModel | null) => void;
    /**
     * Callback on session connection changed.
     */
    onSessionConnection?: OnSessionConnection;
}
/**
 * Simple notebook component without adapter and stores.
 *
 * Notes:
 * - You must provide the appropriate service manager
 * - You can specified the kernel id to use; if it is not defined or empty and startDefaultKernel is true, a new kernel will be started.
 */
export declare function Notebook2(props: React.PropsWithChildren<INotebook2Props>): JSX.Element;
