import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useEffect, useState } from 'react';
import { Box } from '@primer/react';
import { Loader } from '../utils';
import { BaseNotebook, useKernelId, useNotebookModel } from './NotebookBase';
import './Notebook.css';
/**
 * Simple notebook component without adapter and stores.
 *
 * Notes:
 * - You must provide the appropriate service manager
 * - You can specified the kernel id to use; if it is not defined or empty and startDefaultKernel is true, a new kernel will be started.
 */
export function Notebook2(props) {
    const { Toolbar, children, cellSidebarMargin = 120, collaborationServer, commands, extensions, height = '100vh', maxHeight = '100vh', id, nbformat, onNotebookModelChanged, onSessionConnection, path, readonly = false, renderers, serviceManager, startDefaultKernel = false, url, } = props;
    const [isLoading, setIsLoading] = useState(true);
    const kernelId = useKernelId({
        requestedKernelId: props.kernelId,
        kernels: serviceManager.kernels,
        startDefaultKernel,
    });
    const model = useNotebookModel({
        collaborationServer,
        nbformat,
        readonly,
        url,
    });
    useEffect(() => {
        if (model) {
            setIsLoading(false);
        }
        onNotebookModelChanged?.(model);
    }, [model, onNotebookModelChanged]);
    useEffect(() => {
        // Set user identity if collaborating using Jupyter collaboration
        const setUserIdentity = () => {
            if (collaborationServer?.type === 'jupyter' && model) {
                // Yjs details are hidden from the interface
                model.sharedModel.awareness.setLocalStateField('user', serviceManager.user.identity);
            }
        };
        setUserIdentity();
        serviceManager.user.userChanged.connect(setUserIdentity);
        return () => {
            serviceManager.user.userChanged.disconnect(setUserIdentity);
        };
    }, [collaborationServer, model, serviceManager]);
    return isLoading ? (_jsx(Loader, {}, "notebook-loader")) : (_jsxs(Box, { style: { height, width: '100%', position: 'relative' }, id: "dla-Jupyter-Notebook", children: [Toolbar && _jsx(Toolbar, { notebookId: id }), _jsxs(Box, { className: "dla-Box-Notebook", sx: {
                    height,
                    maxHeight,
                    width: '100%',
                    overflowY: 'hidden',
                    '& .datalayer-NotebookPanel-header': {
                        minHeight: '50px',
                    },
                    '& .jp-Notebook': {
                        flex: '1 1 auto !important',
                        height: '100%',
                        overflowY: 'scroll',
                    },
                    '& .jp-NotebookPanel': {
                        height: '100% !important',
                        width: '100% !important',
                    },
                    '& .jp-Toolbar': {
                        display: 'none',
                        zIndex: 0,
                    },
                    '& .jp-Toolbar .jp-HTMLSelect.jp-DefaultStyle select': {
                        fontSize: '14px',
                    },
                    '& .jp-Toolbar > .jp-Toolbar-responsive-opener': {
                        display: 'none',
                    },
                    '& .jp-Toolbar-kernelName': {
                        display: 'none',
                    },
                    '& .jp-Cell': {
                        width: `calc(100% - ${cellSidebarMargin}px)`,
                    },
                    '& .jp-Notebook-footer': {
                        width: `calc(100% - ${cellSidebarMargin + 82}px)`,
                    },
                    '& .jp-CodeMirrorEditor': {
                        cursor: 'text !important',
                    },
                    '.dla-Box-Notebook': {
                        position: 'relative',
                    },
                }, children: [children, model && serviceManager && (_jsx(BaseNotebook, { commands: commands, id: id, extensions: extensions, kernelId: kernelId, model: model, path: path, renderers: renderers, serviceManager: serviceManager, onSessionConnectionChanged: onSessionConnection }))] })] }));
}
//# sourceMappingURL=Notebook2.js.map