import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { ChevronDownIcon, ChevronRightIcon, ChevronUpIcon, SquareIcon, XIcon, } from '@primer/octicons-react';
import { ActionMenu, Box, Button } from '@primer/react';
import { NotebookCommandIds } from '../../NotebookCommands';
import CellMetadataEditor from '../metadata/CellMetadataEditor';
/**
 * Cell sidebar class name.
 */
export const DATALAYER_CELL_SIDEBAR_CLASS_NAME = 'dla-CellSidebar-Container';
/**
 * Cell sidebar component
 */
export function CellSidebar(props) {
    const { commands, model, nbgrader } = props;
    return (_jsxs(Box, { className: DATALAYER_CELL_SIDEBAR_CLASS_NAME, sx: {
            '& p': {
                marginBottom: '0 !important',
            },
        }, children: [nbgrader && (_jsx(ActionMenu, { children: _jsx(CellMetadataEditor, { cellModel: model }) })), _jsx(Button, { title: "Run cell", leadingVisual: ChevronRightIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.run).catch(reason => {
                        console.error('Failed to run cell.', reason);
                    });
                }, children: "Run" }), _jsx(Button, { title: "Insert code cell above", leadingVisual: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.insertAbove).catch(reason => {
                        console.error('Failed to insert code cell above.', reason);
                    });
                }, children: "Code" }), _jsx(Button, { title: "Insert markdown cell above", leadingVisual: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.insertAbove, { cellType: 'markdown' })
                        .catch(reason => {
                        console.error('Failed to insert markdown cell above.', reason);
                    });
                }, children: "Markdown" }), model.type === 'code' ? (_jsx(Button, { title: "Convert to markdow cell", leadingVisual: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.changeCellTypeToMarkdown)
                        .catch(reason => {
                        console.error('Failed to change cell type to markdown.', reason);
                    });
                }, children: "To Markdown" })) : (_jsx(Button, { title: "Convert to code cell", leadingVisual: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.changeCellTypeToCode)
                        .catch(reason => {
                        console.error('Failed to change cell type to code.', reason);
                    });
                }, children: "To Code" })), _jsx(Button, { title: "Insert markdown cell below", leadingVisual: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.insertBelow, { cellType: 'markdown' })
                        .catch(reason => {
                        console.error('Failed to insert markdown cell below.', reason);
                    });
                }, children: "Markdown" }), _jsx(Button, { title: "Insert code cell below", leadingVisual: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.insertBelow).catch(reason => {
                        console.error('Failed to insert code cell below.', reason);
                    });
                }, children: "Code" }), _jsx(Button, { title: "Delete cell", leadingVisual: XIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.deleteCells).catch(reason => {
                        console.error('Failed to delete cells.', reason);
                    });
                }, children: "Delete" })] }));
}
export default CellSidebar;
//# sourceMappingURL=CellSidebar.js.map