/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { CodeCell } from '@jupyterlab/cells';
import { NotebookPanel } from '@jupyterlab/notebook';
// import { CodeMirrorEditor } from '@jupyterlab/codemirror';
// import { IInputPrompt } from '@jupyterlab/cells';
// import { NotebookInputPrompt } from './../cell/InputPrompt';
export const PYTHON_CELL_MIMETYPE = 'text/x-ipython';
export const SQL_CELL_MIMETYPE = 'application/sql';
export const isSQLCell = (cell) => {
    // Note: sometimes model is null
    const datalayer = cell.model?.getMetadata('datalayer');
    if (datalayer) {
        return datalayer['sql'] === true;
    }
    return false;
};
class DatalayerCodeCell extends CodeCell {
    constructor(options) {
        super(options);
    }
}
/**
 * Extend the default implementation NotebookPanel.ContentFactory of `IContentFactory`.
 */
export class JupyterReactContentFactory extends NotebookPanel.ContentFactory {
    _updateSQLEditor = (cell) => {
        if (isSQLCell(cell)) {
            cell.editor.model.mimeType = SQL_CELL_MIMETYPE;
        }
    };
    _updateEditor = (cell) => {
        if (cell.editor) {
            cell.editor.model.mimeTypeChanged.connect((_, args) => {
                this._updateSQLEditor(cell);
            });
            this._updateSQLEditor(cell);
        }
    };
    /** @override */
    createNotebook(options) {
        const notebook = super.createNotebook(options);
        return notebook;
    }
    /** @override */
    createCodeCell(options) {
        const cell = new DatalayerCodeCell(options);
        if (cell.inViewport) {
            this._updateEditor(cell);
        }
        cell.displayChanged.connect(() => {
            this._updateEditor(cell);
        });
        cell.inViewportChanged.connect(() => {
            this._updateEditor(cell);
        });
        return cell;
    }
}
export default JupyterReactContentFactory;
//# sourceMappingURL=JupyterReactContentFactory.js.map