/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
/**
 * Execute code on an output area.
 */
export async function execute(id, code, output, kernel, metadata, suppressCodeExecutionErrors = false, onExecutionPhaseChanged) {
    // Override the default for `stop_on_error`.
    let stopOnError = true;
    if (metadata &&
        Array.isArray(metadata.tags) &&
        metadata.tags.indexOf('raises-exception') !== -1) {
        stopOnError = false;
    }
    const kernelExecutor = kernel.execute(code, {
        model: output.model,
        stopOnError,
        suppressCodeExecutionErrors,
        onExecutionPhaseChanged,
    });
    const future = kernelExecutor.future;
    // TODO fix in upstream jupyterlab if possible...
    output._onIOPub = future.onIOPub;
    output._onExecuteReply = future.onReply;
    output.future = future;
    return future?.done;
}
//# sourceMappingURL=OutputExecutor.js.map