import { Fragment as _Fragment, jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { Box, Button, ButtonGroup, SegmentedControl } from '@primer/react';
import { useMemo, useState } from 'react';
import { createRoot } from 'react-dom/client';
import Cell from '../components/cell/Cell';
import { useCellsStore } from '../components/cell/CellState';
import Console from '../components/console/Console';
import FileBrowser from '../components/filebrowser/FileBrowser';
import FileManagerJupyterLab from '../components/filemanager/FileManagerJupyterLab';
import CellSidebarButton from '../components/notebook/cell/sidebar/CellSidebarButton';
import { Notebook } from '../components/notebook/Notebook';
import useNotebookStore from '../components/notebook/NotebookState';
import Output from '../components/output/Output';
import Terminal from '../components/terminal/Terminal';
import { DEFAULT_JUPYTER_SERVER_TOKEN, DEFAULT_JUPYTER_SERVER_URL, } from '../jupyter';
import { Jupyter } from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { Kernel } from '../jupyter/kernel/Kernel';
import { CellSidebarExtension } from '../components';
import notebook from './notebooks/NotebookExample1.ipynb.json';
const SOURCE_1 = '1+1';
const NOTEBOOK_ID_1 = 'notebook-1-id';
const NOTEBOOK_ID_2 = 'notebook-2-id';
const NOTEBOOK_ID_3 = 'notebook-3-id';
const SOURCE_1_OUTPUTS = [
    {
        data: {
            'text/plain': ['2'],
        },
        execution_count: 1,
        metadata: {},
        output_type: 'execute_result',
    },
];
const SOURCE_2 = `import ipywidgets as widgets
widgets.IntSlider(
    value=7,
    min=0,
    max=10,
    step=1
 )`;
const CellPreview = (props) => {
    const cellsStore = useCellsStore();
    return (_jsxs(_Fragment, { children: [_jsxs(_Fragment, { children: ["source: ", cellsStore.getSource(props.id)] }), _jsxs(_Fragment, { children: ["kernel available:", ' ', String(cellsStore.isKernelSessionAvailable(props.id))] })] }));
};
const CellToolbar = (props) => {
    const { id } = props;
    const cellsStore = useCellsStore();
    return (_jsxs(_Fragment, { children: [_jsx(Box, { display: "flex", children: _jsxs(ButtonGroup, { children: [_jsx(Button, { variant: "default", size: "small", onClick: () => cellsStore.execute(id), children: "Run the cell" }), _jsx(Button, { variant: "invisible", size: "small", onClick: () => cellsStore.setOutputsCount(id, 0), children: "Reset outputs count" })] }) }), _jsxs(Box, { children: ["Outputs count: ", cellsStore.getOutputsCount(id)] })] }));
};
const NotebookToolbar = () => {
    const notebookStore = useNotebookStore();
    return (_jsx(Box, { display: "flex", children: _jsxs(ButtonGroup, { children: [_jsx(Button, { variant: "default", size: "small", onClick: () => notebookStore.save({
                        id: NOTEBOOK_ID_1,
                        date: new Date(),
                    }), children: "Save the notebook" }), _jsx(Button, { variant: "default", size: "small", onClick: () => notebookStore.runAll(NOTEBOOK_ID_1), children: "Run all" })] }) }));
};
const NotebookKernelChange = () => {
    const { kernelManager, serviceManager } = useJupyter();
    const notebookStore = useNotebookStore();
    const extensions = useMemo(() => [new CellSidebarExtension()], []);
    const changeKernel = () => {
        if (serviceManager && kernelManager) {
            const kernel = new Kernel({
                kernelManager,
                kernelName: 'defaultKernel',
                kernelSpecName: 'python',
                kernelspecsManager: serviceManager.kernelspecs,
                sessionManager: serviceManager.sessions,
            });
            kernel.ready.then(() => {
                notebookStore.changeKernel({ id: NOTEBOOK_ID_2, kernel });
                alert('Kernel is changed.');
            });
        }
    };
    return (_jsxs(_Fragment, { children: [_jsx(Box, { display: "flex", children: _jsx(ButtonGroup, { children: _jsx(Button, { variant: "default", size: "small", onClick: changeKernel, children: "Switch Kernel" }) }) }), _jsx(Notebook, { path: "test.ipynb", extensions: extensions, id: NOTEBOOK_ID_2 })] }));
};
const Outputs = () => {
    const { defaultKernel } = useJupyter();
    return (_jsxs(_Fragment, { children: [_jsx(Output, { showEditor: true, autoRun: false, kernel: defaultKernel, code: SOURCE_1, outputs: SOURCE_1_OUTPUTS }), _jsx(Output, { showEditor: true, autoRun: false, kernel: defaultKernel, code: SOURCE_2 }), _jsx(Output, { showEditor: true, autoRun: true, kernel: defaultKernel, code: SOURCE_2 })] }));
};
const JupyterContextExample = () => {
    const [index, setIndex] = useState(1);
    const { serviceManager } = useJupyter();
    const extensionsButton = useMemo(() => [new CellSidebarExtension({ factory: CellSidebarButton })], []);
    const extensions = useMemo(() => [new CellSidebarExtension()], []);
    return (_jsx(_Fragment, { children: _jsxs(Jupyter, { jupyterServerUrl: DEFAULT_JUPYTER_SERVER_URL, jupyterServerToken: DEFAULT_JUPYTER_SERVER_TOKEN, serverless: index === 0, terminals: true, children: [_jsxs(SegmentedControl, { onChange: index => setIndex(index), "aria-label": "jupyter-react-example", children: [_jsx(SegmentedControl.Button, { defaultSelected: index === 0, children: "Serverless" }), _jsx(SegmentedControl.Button, { defaultSelected: index === 1, children: "Server" })] }), _jsx("hr", {}), _jsx(CellPreview, { id: cellId }), _jsx(CellToolbar, { id: cellId }), _jsx(Cell, { id: cellId }), _jsx("hr", {}), _jsx(Notebook, { nbformat: notebook, id: NOTEBOOK_ID_3, height: "300px", extensions: extensionsButton, Toolbar: NotebookToolbar }), _jsx("hr", {}), _jsx(Console, {}), _jsx("hr", {}), _jsx(Outputs, {}), _jsx("hr", {}), _jsx(NotebookToolbar, {}), _jsx(Notebook, { path: "ipywidgets.ipynb", extensions: extensions, id: NOTEBOOK_ID_1 }), _jsx("hr", {}), _jsx(NotebookKernelChange, {}), _jsx("hr", {}), _jsx(FileManagerJupyterLab, {}), _jsx("hr", {}), serviceManager && _jsx(FileBrowser, { serviceManager: serviceManager }), _jsx("hr", {}), _jsx(Terminal, {})] }) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
const cellId = 'my-cell-1';
root.render(_jsx(JupyterContextExample, {}));
//# sourceMappingURL=JupyterContext.js.map