import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState, useEffect, useCallback } from 'react';
import { createRoot } from 'react-dom/client';
import { Box, Button, Heading, Text, Link, PageLayout, PageHeader, RadioGroup, Radio, FormControl, RelativeTime, TextInput, TextInputWithTokens, Timeline, ToggleSwitch, SegmentedControl, Label, LabelGroup, NavList, IconButton, CircleBadge, CircleOcticon, Tooltip, } from '@primer/react';
import { DataTable, Table, SkeletonBox, Banner } from '@primer/react/experimental';
import { GitCommitIcon, HeartIcon, RocketIcon, CheckIcon } from '@primer/octicons-react';
import { Jupyter } from '../jupyter/Jupyter';
import { jupyterLabTheme as theme } from '../theme/themes';
const mockTokens = [
    { text: 'zero', id: 0 },
    { text: 'one', id: 1 },
    { text: 'two', id: 2 },
    { text: 'three', id: 3 },
    { text: 'four', id: 4 },
    { text: 'five', id: 5 },
    { text: 'six', id: 6 },
    { text: 'seven', id: 7 },
];
const now = Date.now();
const Second = 1000;
const Minute = 60 * Second;
const Hour = 60 * Minute;
const Day = 24 * Hour;
const Week = 7 * Day;
const Month = 4 * Week;
const data = [
    {
        id: 1,
        name: 'codeql-dca-worker',
        type: 'internal',
        updatedAt: now,
        securityFeatures: {
            dependabot: ['alerts', 'security updates'],
            codeScanning: ['report secrets'],
        },
    },
    {
        id: 2,
        name: 'aegir',
        type: 'public',
        updatedAt: now - 5 * Minute,
        securityFeatures: {
            dependabot: ['alerts'],
            codeScanning: ['report secrets'],
        },
    },
    {
        id: 3,
        name: 'strapi',
        type: 'public',
        updatedAt: now - 1 * Hour,
        securityFeatures: {
            dependabot: [],
            codeScanning: [],
        },
    },
    {
        id: 4,
        name: 'codeql-ci-nightlies',
        type: 'public',
        updatedAt: now - 6 * Hour,
        securityFeatures: {
            dependabot: ['alerts'],
            codeScanning: [],
        },
    },
    {
        id: 5,
        name: 'dependabot-updates',
        type: 'public',
        updatedAt: now - 1 * Day,
        securityFeatures: {
            dependabot: [],
            codeScanning: [],
        },
    },
    {
        id: 6,
        name: 'tsx-create-react-app',
        type: 'public',
        updatedAt: now - 1 * Week,
        securityFeatures: {
            dependabot: [],
            codeScanning: [],
        },
    },
    {
        id: 7,
        name: 'bootstrap',
        type: 'public',
        updatedAt: now - 1 * Month,
        securityFeatures: {
            dependabot: ['alerts'],
            codeScanning: [],
        },
    },
    {
        id: 8,
        name: 'docker-templates',
        type: 'public',
        updatedAt: now - 3 * Month,
        securityFeatures: {
            dependabot: ['alerts'],
            codeScanning: [],
        },
    },
];
const JupyterLabTheme = () => {
    const [colormode, setColormode] = useState('light');
    const [tokens, setTokens] = useState([...mockTokens].slice(0, 3));
    const [isOn, setIsOn] = useState(false);
    useEffect(() => {
        if (isOn) {
            setColormode('dark');
        }
        else {
            setColormode('light');
        }
    }, [isOn]);
    const onClick = useCallback(() => {
        setIsOn(!isOn);
    }, [isOn]);
    const handleSwitchChange = useCallback((on) => {
        setIsOn(on);
    }, []);
    const onTokenRemove = (tokenId) => {
        setTokens(tokens.filter((token) => token.id !== tokenId));
    };
    return (_jsx(Jupyter, { theme: theme, colormode: colormode, startDefaultKernel: true, children: _jsxs(PageLayout, { containerWidth: "full", padding: "normal", children: [_jsx(PageLayout.Header, { children: _jsxs(PageHeader, { children: [_jsx(PageHeader.TitleArea, { variant: "large", children: _jsx(PageHeader.Title, { children: "JupyterLab Theme" }) }), _jsx(PageHeader.Description, { children: _jsx(Text, { sx: {
                                        fontSize: 1,
                                        color: 'fg.muted'
                                    }, children: "Relevant examples to create a data driven user interface with Datalayer." }) }), _jsxs(PageHeader.Actions, { children: [_jsxs(Text, { fontSize: 2, fontWeight: "bold", id: "switch-label", display: "block", mb: 1, children: [colormode === 'light' ? 'Light' : 'Dark', " Mode"] }), _jsx(ToggleSwitch, { size: "small", onClick: onClick, onChange: handleSwitchChange, checked: isOn, statusLabelPosition: "end", "aria-labelledby": "switch-label" })] })] }) }), _jsxs(PageLayout.Content, { children: [_jsx(Box, { children: _jsx(Box, { children: _jsx(Banner, { title: "Info", description: "Datalayer users are now required to enable two-factor authentication as an additional security measure." }) }) }), _jsxs(Box, { display: "flex", children: [_jsxs(Box, { sx: { width: "100%" }, children: [_jsx(Heading, { children: "Heading" }), _jsxs(Box, { children: [_jsx(Text, { as: "h1", children: "Heading 1" }), _jsx(Text, { as: "h2", children: "Heading 2" }), _jsx(Text, { as: "h3", children: "Heading 3" }), _jsx(Text, { children: "This is a text." }), _jsx("br", {}), _jsx(Link, { href: "https://datalayer.io", target: "_blank", children: "This is a link." }), _jsx("br", {}), _jsx(Text, { as: "h3", children: _jsx(Link, { href: "https://datalayer.io", target: "_blank", children: "This is a heading 3 link" }) })] }), _jsxs(Box, { children: [_jsx(Button, { variant: "default", children: "Default" }), _jsx(Button, { variant: "default", leadingVisual: RocketIcon, children: "Icon" }), _jsx(Button, { variant: "primary", children: "Primary" }), _jsx(Button, { variant: "primary", leadingVisual: RocketIcon, children: "Icon" }), _jsx(Button, { variant: "invisible", children: "Invisible" }), _jsx(Button, { variant: "invisible", leadingVisual: RocketIcon, children: "Icon" }), _jsx(Button, { variant: "danger", children: "Danger" }), _jsx(Button, { variant: "danger", leadingVisual: RocketIcon, children: "Icon" })] }), _jsx(Box, { children: _jsxs(NavList, { children: [_jsx(NavList.Item, { href: "#", "aria-current": "page", children: "Item 1" }), _jsx(NavList.Item, { href: "#", children: "Item 2" }), _jsx(NavList.Item, { href: "#", children: "Item 3" })] }) }), _jsx(Box, { children: _jsx(IconButton, { icon: HeartIcon, "aria-label": "Favorite" }) }), _jsx(Box, { children: _jsx(CircleOcticon, { icon: CheckIcon, sx: { backgroundColor: 'success.emphasis', color: 'fg.onEmphasis' }, "aria-label": "Changes approved" }) }), _jsx(Box, { children: _jsx(CircleBadge, { children: _jsx(CircleBadge.Icon, { icon: RocketIcon, "aria-label": "Launch badge" }) }) })] }), _jsxs(Box, { sx: { width: "100%" }, children: [_jsx(Box, { as: "form", children: _jsxs(RadioGroup, { name: "defaultRadioGroup", children: [_jsx(RadioGroup.Label, { children: "Choices" }), _jsxs(FormControl, { children: [_jsx(Radio, { value: "one", defaultChecked: true }), _jsx(FormControl.Label, { children: "Choice one" })] }), _jsxs(FormControl, { children: [_jsx(Radio, { value: "two" }), _jsx(FormControl.Label, { children: "Choice two" })] }), _jsxs(FormControl, { children: [_jsx(Radio, { value: "three" }), _jsx(FormControl.Label, { children: "Choice three" })] })] }) }), _jsx(Box, { as: "form", children: _jsxs(FormControl, { children: [_jsx(FormControl.Label, { children: "Default label" }), _jsx(FormControl.Caption, { children: "This is a caption" }), _jsx(TextInput, {})] }) }), _jsx(Box, { children: _jsxs(FormControl, { children: [_jsx(FormControl.Label, { children: "Default label" }), _jsx(TextInputWithTokens, { tokens: tokens, onTokenRemove: onTokenRemove })] }) }), _jsx(Box, { children: _jsx(SkeletonBox, { height: "4rem" }) }), _jsxs(Box, { children: [_jsx(Text, { id: "toggle", fontWeight: "bold", fontSize: 1, children: "Toggle label" }), _jsx(ToggleSwitch, { "aria-labelledby": "toggle" })] }), _jsx(Box, { children: _jsxs(SegmentedControl, { "aria-label": "File view", children: [_jsx(SegmentedControl.Button, { defaultSelected: true, children: "Preview" }), _jsx(SegmentedControl.Button, { children: "Raw" }), _jsx(SegmentedControl.Button, { children: "Blame" })] }) }), _jsx(Box, { children: _jsxs(Timeline, { children: [_jsxs(Timeline.Item, { children: [_jsx(Timeline.Badge, { children: _jsx(CircleOcticon, { icon: GitCommitIcon, "aria-label": "Commit" }) }), _jsx(Timeline.Body, { children: "This is a message" })] }), _jsxs(Timeline.Item, { children: [_jsx(Timeline.Badge, { children: _jsx(CircleOcticon, { icon: GitCommitIcon, "aria-label": "Commit" }) }), _jsx(Timeline.Body, { children: "This is a message" })] })] }) }), _jsx(Box, { children: _jsx(Tooltip, { text: "This is a tooltip", children: _jsx(Button, { variant: "default", children: "Hover me" }) }) }), _jsxs(Box, { children: [_jsx("p", { children: "Trunacte after 5 labels" }), _jsxs(LabelGroup, { visibleChildCount: 5, children: [_jsx(Label, { children: "One" }), _jsx(Label, { children: "Two" }), _jsx(Label, { children: "Three" }), _jsx(Label, { children: "Four" }), _jsx(Label, { children: "Five" }), _jsx(Label, { children: "Six" }), _jsx(Label, { children: "Seven" }), _jsx(Label, { children: "Eight" }), _jsx(Label, { children: "Nine" }), _jsx(Label, { children: "Ten" }), _jsx(Label, { children: "Eleven" }), _jsx(Label, { children: "Twelve" }), _jsx(Label, { children: "Thirteen" }), _jsx(Label, { children: "Fourteen" }), _jsx(Label, { children: "Fifteen" }), _jsx(Label, { children: "Sixteen" })] }), _jsx("p", { children: "Truncate labels based on container size" }), _jsx(Box, { sx: {
                                                        outline: '1px solid',
                                                        outlineColor: 'border.default',
                                                        overflow: 'auto',
                                                        padding: '0.25rem',
                                                        resize: 'horizontal',
                                                        width: '600px',
                                                    }, children: _jsxs(LabelGroup, { visibleChildCount: "auto", children: [_jsx(Label, { variant: "default", children: "One" }), _jsx(Label, { variant: "accent", children: "Two" }), _jsx(Label, { variant: "attention", children: "Three" }), _jsx(Label, { variant: "danger", children: "Four" }), _jsx(Label, { variant: "done", children: "Five" }), _jsx(Label, { variant: "primary", children: "Six" }), _jsx(Label, { variant: "secondary", children: "Seven" }), _jsx(Label, { variant: "severe", children: "Eight" }), _jsx(Label, { variant: "sponsors", children: "Nine" }), _jsx(Label, { variant: "success", children: "Ten" }), _jsx(Label, { children: "Eleven" }), _jsx(Label, { children: "Twelve" }), _jsx(Label, { children: "Thirteen" }), _jsx(Label, { children: "Fourteen" }), _jsx(Label, { children: "Fifteen" }), _jsx(Label, { children: "Sixteen" })] }) })] })] })] }), _jsx(Box, { children: _jsxs(Table.Container, { children: [_jsx(Table.Title, { as: "h2", id: "repositories", children: "Repositories" }), _jsx(Table.Subtitle, { as: "p", id: "repositories-subtitle", children: "A subtitle could appear here to give extra context to the data." }), _jsx(DataTable, { "aria-labelledby": "repositories", "aria-describedby": "repositories-subtitle", data: data, columns: [
                                            // @ts-ignore
                                            {
                                                header: 'Repository',
                                                field: 'name',
                                                rowHeader: true,
                                            },
                                            {
                                                header: 'Type',
                                                field: 'type',
                                                renderCell: (row) => {
                                                    return _jsx(Label, { children: row.type });
                                                },
                                            },
                                            {
                                                header: 'Updated',
                                                field: 'updatedAt',
                                                renderCell: (row) => {
                                                    return _jsx(RelativeTime, { date: new Date(row.updatedAt) });
                                                },
                                            },
                                            {
                                                header: 'Dependabot',
                                                field: 'securityFeatures.dependabot',
                                                renderCell: (row) => {
                                                    return row.securityFeatures.dependabot.length > 0 ? (_jsx(LabelGroup, { children: row.securityFeatures.dependabot.map((feature) => {
                                                            return _jsx(Label, { children: feature }, feature);
                                                        }) })) : null;
                                                },
                                            },
                                            {
                                                header: 'Code scanning',
                                                field: 'securityFeatures.codeScanning',
                                                renderCell: (row) => {
                                                    return row.securityFeatures.codeScanning.length > 0 ? (_jsx(LabelGroup, { children: row.securityFeatures.codeScanning.map((feature) => {
                                                            return _jsx(Label, { variant: "danger", children: feature }, feature);
                                                        }) })) : null;
                                                },
                                            },
                                        ] })] }) }), _jsxs(Box, { children: [_jsx(Box, { children: _jsx(Text, { as: "h3", children: _jsx(Link, { href: "https://datalayer.io", target: "_blank", children: "User Guide" }) }) }), _jsx(Box, { children: _jsx(Text, { as: "h3", children: _jsx(Link, { href: "https://datalayer.io", target: "_blank", children: "Pricing" }) }) }), _jsx(Box, { children: _jsx(Text, { as: "h3", children: _jsx(Link, { href: "https://datalayer.io", target: "_blank", children: "Privacy" }) }) }), _jsx(Box, { children: _jsx(Text, { as: "h3", children: _jsx(Link, { href: "https://datalayer.io", target: "_blank", children: "Terms and conditions" }) }) })] })] })] }) }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(JupyterLabTheme, {}));
//# sourceMappingURL=JupyterLabTheme.js.map