import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { Box, Button, Flash } from '@primer/react';
import { useMemo, useState } from 'react';
import { createRoot } from 'react-dom/client';
import { CellSidebarExtension } from '../components';
import { Notebook } from '../components/notebook/Notebook';
import useNotebookStore from '../components/notebook/NotebookState';
import { Jupyter } from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { Kernel } from '../jupyter/kernel/Kernel';
const NOTEBOOK_ID = 'notebook-kernel-change-id';
const PYTHON_KERNEL_NAME = 'python';
const DENO_KERNEL_NAME = 'deno';
const NotebookKernelChange = () => {
    const { kernelManager, serviceManager, kernel } = useJupyter();
    const [message, setMessage] = useState("");
    const notebookStore = useNotebookStore();
    const notebook = notebookStore.selectNotebook(NOTEBOOK_ID);
    const extensions = useMemo(() => [new CellSidebarExtension()], []);
    const changeKernel = () => {
        if (kernelManager && serviceManager) {
            const newKernel = new Kernel({
                kernelManager,
                kernelName: DENO_KERNEL_NAME,
                kernelSpecName: DENO_KERNEL_NAME,
                kernelspecsManager: serviceManager.kernelspecs,
                sessionManager: serviceManager.sessions,
            });
            newKernel.ready.then(() => {
                notebookStore.changeKernel({ id: NOTEBOOK_ID, kernel: newKernel });
                setMessage(`🥺 Bummer, all your variables are lost! The kernel was ${PYTHON_KERNEL_NAME} and is now ${DENO_KERNEL_NAME}). Try with: import pl from "npm:nodejs-polars";`);
            });
        }
    };
    return (_jsxs(Jupyter, { defaultKernelName: PYTHON_KERNEL_NAME, children: [_jsxs(Box, { display: "flex", children: [_jsx(Box, { children: _jsx(Button, { variant: "default", size: "small", onClick: changeKernel, children: "Assign another Kernel" }) }), _jsxs(Box, { ml: 3, children: ["Kernel ID: ", kernel?.id] }), _jsxs(Box, { ml: 3, children: ["Kernel Client ID: ", notebook?.adapter?.kernel?.clientId] }), _jsxs(Box, { ml: 3, children: ["Kernel Session ID: ", notebook?.adapter?.kernel?.session.id] }), _jsxs(Box, { ml: 3, children: ["Kernel Info: ", notebook?.adapter?.kernel?.info?.language_info.name] })] }), message &&
                _jsx(Box, { children: _jsx(Flash, { children: message }) }), _jsx(Notebook, { id: NOTEBOOK_ID, path: "test.ipynb", height: "500px", extensions: extensions })] }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsx(NotebookKernelChange, {}));
//# sourceMappingURL=NotebookKernelChange.js.map