import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { Box, Text } from '@primer/react';
import { useEffect, useState } from 'react';
import { createRoot } from 'react-dom/client';
import { KernelIndicator } from '../components/kernel/Kernelndicator';
import { Output } from '../components/output/Output';
import { Jupyter } from '../jupyter/Jupyter';
import { useJupyter } from '../jupyter/JupyterContext';
import { Kernel } from '../jupyter/kernel/Kernel';
import { useKernelsStore } from '../jupyter/kernel/KernelState';
import { newUuid } from '../utils/Utils';
import { useOutputsStore } from './../components/output/OutputState';
const SOURCE_ID_1 = 'output-id-1';
const OUTPUTS_1 = [
    {
        data: {
            'text/plain': ['2'],
        },
        execution_count: 1,
        metadata: {},
        output_type: 'execute_result',
    },
];
const SOURCE_ID_2 = 'output-id-2';
const SOURCE_2 = '2+2';
const OUTPUTS_2 = [
    {
        data: {
            'text/plain': ['4'],
        },
        execution_count: 1,
        metadata: {},
        output_type: 'execute_result',
    },
];
const SOURCE_ID_3 = 'output-id-3';
const SOURCE_3 = 'x=2';
const OUTPUTS_3 = [
    {
        data: {
            'text/plain': ['2'],
        },
        execution_count: 1,
        metadata: {},
        output_type: 'execute_result',
    },
];
const OutputWithoutEditor = () => {
    const outputStore = useOutputsStore();
    console.log('Outputs 1', outputStore.getModel(SOURCE_ID_1)?.toJSON(), outputStore.getInput(SOURCE_ID_1));
    return (_jsxs(_Fragment, { children: [_jsx(Text, { as: "h1", children: "Output without Code Editor" }), _jsx(Output, { autoRun: false, id: SOURCE_ID_1, outputs: OUTPUTS_1, showEditor: false })] }));
};
const OutputWithEditor = () => {
    const { defaultKernel } = useJupyter();
    const outputStore = useOutputsStore();
    console.log('Outputs 2', outputStore.getModel(SOURCE_ID_2)?.toJSON(), outputStore.getInput(SOURCE_ID_2));
    return (_jsxs(_Fragment, { children: [_jsx(Text, { as: "h1", children: "Output with Code Editor" }), _jsx(Output, { autoRun: false, code: SOURCE_2, id: SOURCE_ID_2, kernel: defaultKernel, outputs: OUTPUTS_2, showEditor: true })] }));
};
const OutputWithEmptyOutput = () => {
    const { kernelManager, serviceManager } = useJupyter();
    const outputStore = useOutputsStore();
    const kernelsStore = useKernelsStore();
    const [kernel, setKernel] = useState();
    useEffect(() => {
        if (serviceManager && kernelManager) {
            const kernel = new Kernel({
                path: newUuid(),
                kernelName: 'kernel-example',
                kernelSpecName: 'python',
                kernelManager,
                kernelspecsManager: serviceManager.kernelspecs,
                sessionManager: serviceManager.sessions,
            });
            setKernel(kernel);
        }
    }, [serviceManager, kernelManager]);
    console.log('Outputs 3', outputStore.getModel(SOURCE_ID_3)?.toJSON(), outputStore.getInput(SOURCE_ID_3));
    return (_jsxs(_Fragment, { children: [_jsx(Text, { as: "h1", children: "Output with empty Output" }), kernel &&
                _jsxs(_Fragment, { children: [_jsxs(Box, { children: ["Kernel State: ", kernelsStore.getExecutionState(kernel.id)] }), _jsxs(Box, { children: ["Kernel Phase: ", kernelsStore.getExecutionPhase(kernel.id)] }), _jsx(Box, { children: _jsx(KernelIndicator, { kernel: kernel.connection }) }), _jsx(Box, { children: _jsx(Output, { autoRun: false, code: SOURCE_3, id: SOURCE_ID_3, kernel: kernel, outputs: OUTPUTS_3, showEditor: true }) })] })] }));
};
const div = document.createElement('div');
document.body.appendChild(div);
const root = createRoot(div);
root.render(_jsxs(Jupyter, { startDefaultKernel: true, children: [_jsx(OutputWithoutEditor, {}), _jsx(OutputWithEditor, {}), _jsx(OutputWithEmptyOutput, {})] }));
//# sourceMappingURL=Output.js.map