import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { ChevronDownIcon, ChevronRightIcon, ChevronUpIcon, SquareIcon, XIcon, } from '@primer/octicons-react';
import { ActionMenu, Box, Button } from '@primer/react';
import { NotebookCommandIds } from '../../../components/notebook';
import { CellMetadataEditor } from '../../../components/notebook/cell/metadata';
import { DATALAYER_CELL_SIDEBAR_CLASS_NAME, } from '../../../components/notebook/cell/sidebar';
export const CellSidebarSource = (props) => {
    const { commands, model, nbgrader } = props;
    return (_jsxs(Box, { className: DATALAYER_CELL_SIDEBAR_CLASS_NAME, sx: {
            '& p': {
                marginBottom: '0 !important',
            },
        }, children: [_jsx(Button, { leadingVisual: ChevronRightIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.run).catch(reason => {
                        console.error('Failed to run cell.', reason);
                    });
                }, children: "Run" }), _jsx(Button, { leadingVisual: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.insertAbove).catch(reason => {
                        console.error('Failed to insert code cell above.', reason);
                    });
                }, children: "Code (with source)" }), _jsx(Button, { leadingVisual: ChevronUpIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.insertAbove, { cellType: 'markdown' })
                        .catch(reason => {
                        console.error('Failed to insert markdown cell above.', reason);
                    });
                }, children: "Markdown" }), model.type === 'code' ? (_jsx(Button, { leadingVisual: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.changeCellTypeToMarkdown)
                        .catch(reason => {
                        console.error('Failed to change cell type to markdown.', reason);
                    });
                }, children: "To Markdown" })) : (_jsx(Button, { leadingVisual: SquareIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.changeCellTypeToCode)
                        .catch(reason => {
                        console.error('Failed to change cell type to code.', reason);
                    });
                }, children: "To Code" })), _jsx(Button, { leadingVisual: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands
                        .execute(NotebookCommandIds.insertBelow, { cellType: 'markdown' })
                        .catch(reason => {
                        console.error('Failed to insert markdown cell below.', reason);
                    });
                }, children: "Markdown" }), _jsx(Button, { leadingVisual: ChevronDownIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.insertBelow).catch(reason => {
                        console.error('Failed to insert code cell below.', reason);
                    });
                }, children: "Code (with source)" }), _jsx(Button, { leadingVisual: XIcon, variant: "invisible", size: "small", onClick: (e) => {
                    e.preventDefault();
                    commands.execute(NotebookCommandIds.deleteCells).catch(reason => {
                        console.error('Failed to delete cells.', reason);
                    });
                }, children: "Delete" }), nbgrader && (_jsx(ActionMenu, { children: _jsx(CellMetadataEditor, { cellModel: model }) }))] }));
};
export default CellSidebarSource;
//# sourceMappingURL=CellSidebarSource.js.map