import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { BaseStyles, Box, ThemeProvider } from '@primer/react';
import { useMemo } from 'react';
import { ErrorBoundary } from 'react-error-boundary';
import { loadJupyterConfig } from './JupyterConfig';
import { JupyterContextProvider } from './JupyterContext';
import { jupyterLabTheme, JupyterLabCss } from '../theme';
/**
 * The component to be used as fallback in case of error.
 */
const ErrorFallback = ({ error, resetErrorBoundary }) => {
    return (_jsxs("div", { role: "alert", children: [_jsx("p", { children: "Oops, something went wrong." }), _jsx("pre", { children: error.message }), _jsx("div", { style: { visibility: 'hidden' }, children: _jsx("button", { onClick: resetErrorBoundary, children: "Try again" }) })] }));
};
/**
 * The Jupyter context. This handles the needed initialization
 * and ensure the Primer theme providers is available.
 */
export const Jupyter = (props) => {
    const { children, collaborative, colormode, defaultKernelName, disableCssLoading = false, initCode, jupyterServerUrl, jupyterServerToken, lite, serverless, serviceManager, startDefaultKernel, skeleton, terminals, theme, useRunningKernelId, useRunningKernelIndex, } = props;
    const config = useMemo(() => {
        return loadJupyterConfig({
            collaborative,
            jupyterServerUrl,
            jupyterServerToken,
            lite,
            terminals,
        });
    }, [props]);
    return (_jsx(ErrorBoundary, { FallbackComponent: ErrorFallback, onReset: () => { console.log('Error Boundary reset has been invoked...'); }, children: _jsx(ThemeProvider, { theme: theme, colorMode: colormode === 'light' ? 'day' : 'night', dayScheme: "light", nightScheme: "dark", children: _jsx(BaseStyles, { children: _jsxs(Box, { color: "fg.default", bg: "canvas.default", children: [!config.insideJupyterLab && !disableCssLoading &&
                            _jsx(JupyterLabCss, { colormode: colormode }), _jsx(JupyterContextProvider, { collaborative: collaborative, defaultKernelName: defaultKernelName, initCode: initCode, lite: lite, serverless: serverless, serviceManager: serviceManager, skeleton: skeleton, startDefaultKernel: startDefaultKernel, useRunningKernelId: useRunningKernelId, useRunningKernelIndex: useRunningKernelIndex, children: children })] }) }) }) }));
};
Jupyter.defaultProps = {
    colormode: 'light',
    disableCssLoading: false,
    terminals: false,
    theme: jupyterLabTheme,
};
export default Jupyter;
//# sourceMappingURL=Jupyter.js.map