/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { URLExt } from '@jupyterlab/coreutils';
import { ServerConnection } from '@jupyterlab/services';
export const COLLABORATION_ROOM_URL_PATH = 'api/collaboration/room';
export const COLLABORATION_SESSION_URL_PATH = 'api/collaboration/session';
export async function requestDocSession(format, type, path, serverSettings) {
    const settings = serverSettings ?? ServerConnection.makeSettings();
    const url = URLExt.join(settings.baseUrl, COLLABORATION_SESSION_URL_PATH, encodeURIComponent(path));
    const body = {
        method: 'PUT',
        body: JSON.stringify({ format, type }),
    };
    let response;
    try {
        response = await ServerConnection.makeRequest(url, body, settings);
    }
    catch (error) {
        throw new ServerConnection.NetworkError(error);
    }
    let data = await response.text();
    if (data.length > 0) {
        try {
            data = JSON.parse(data);
        }
        catch (error) {
            console.log('Not a JSON response body.', response);
        }
    }
    if (!response.ok) {
        throw new ServerConnection.ResponseError(response, data.message || data);
    }
    return data;
}
export default {};
//# sourceMappingURL=JupyterCollaboration.js.map