import { ServiceManager, Kernel as JupyterKernel, Session } from '@jupyterlab/services';
import { JupyterPropsType } from '../jupyter';
import { Kernel } from '../jupyter/kernel/Kernel';
import { IJupyterConfig } from '../jupyter/JupyterConfig';
import type { IDatalayerConfig } from './IDatalayerConfig';
import { CellsState } from '../components/cell/CellState';
import { ConsoleState } from '../components/console/ConsoleState';
import { NotebookState } from '../components/notebook/NotebookState';
import { OutputState } from '../components/output/OutputState';
import { TerminalState } from '../components/terminal/TerminalState';
export type OnSessionConnection = (kernelConnection: Session.ISessionConnection | undefined) => void;
export type KernelTransfer = {
    transfer: (to: JupyterKernel.IKernelConnection) => void;
};
export type JupyterReactState = {
    cellsStore: CellsState;
    consoleStore: ConsoleState;
    datalayerConfig?: IDatalayerConfig;
    jupyterConfig?: IJupyterConfig;
    kernel?: Kernel;
    kernelIsLoading: boolean;
    notebookStore: NotebookState;
    outputStore: OutputState;
    serviceManager?: ServiceManager.IManager;
    terminalStore: TerminalState;
    version: string;
    setDatalayerConfig: (configuration?: IDatalayerConfig) => void;
    setJupyterConfig: (configuration?: IJupyterConfig) => void;
    setServiceManager: (serviceManager?: ServiceManager.IManager) => void;
    setVersion: (version: string) => void;
};
export declare const jupyterReactStore: import("zustand").StoreApi<JupyterReactState>;
export declare function useJupyterReactStore(): JupyterReactState;
export declare function useJupyterReactStore<T>(selector: (state: JupyterReactState) => T): T;
export declare function useJupyterReactStoreFromProps(props: JupyterPropsType): JupyterReactState;
export default useJupyterReactStore;
